@@ -35,7 +35,7 @@ prob$objFun(x0)			# Test the obj fn
 head(prob$gradFun(x0))	# Test the grad fn
 
 mani.params <- get.manifold.params(IsCheckParams = TRUE)
-solver.params <- get.solver.params(isconvex = TRUE, DEBUG = 0, Tolerance = 1e-4,
+solver.params <- get.solver.params(DEBUG = 0, Tolerance = 1e-4,
 	Max_Iteration = 1000, IsCheckParams = TRUE, IsCheckGradHess = FALSE)
 mani.defn <- get.stiefel.defn(n, p)
 
