@@ -6,11 +6,11 @@ namespace ROPTLIB{
 
 	void ForDebug::Print(const char *name, const double *M, integer row, integer col, integer num)
 	{
-		std::cout << "=============" << name << "============" << std::endl;
+		OUTSTREAM << "=============" << name << "============" << std::endl;
 		if (col == 1 && num == 1)
 		{
 			for (integer i = 0; i < row; i++)
-				std::cout << M[i] << std::endl;
+				OUTSTREAM << M[i] << std::endl;
 		}
 		else
 			if (num == 1)
@@ -19,23 +19,23 @@ namespace ROPTLIB{
 				{
 					for (integer k = 0; k < col; k++)
 					{
-						std::cout << M[j + row * k] << "\t";
+						OUTSTREAM << M[j + row * k] << "\t";
 					}
-					std::cout << std::endl;
+					OUTSTREAM << std::endl;
 				}
 			}
 			else
 			{
 				for (integer i = 0; i < num; i++)
 				{
-					std::cout << "(:, :, " << i << ")" << std::endl;
+					OUTSTREAM << "(:, :, " << i << ")" << std::endl;
 					for (integer j = 0; j < row; j++)
 					{
 						for (integer k = 0; k < col; k++)
 						{
-							std::cout << M[i * row * col + j + row * k] << "\t";
+							OUTSTREAM << M[i * row * col + j + row * k] << "\t";
 						}
-						std::cout << std::endl;
+						OUTSTREAM << std::endl;
 					}
 				}
 			}
